==> huaweicloudsdkscm-3.1.93-py2.py3-none-any.whl: huaweicloudsdkscm/v3/model/list_deployed_resources_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDeployedResourcesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'results': 'list[ResultDetail]'
    }

    attribute_map = {
        'results': 'results'
    }

    def __init__(self, results=None):
        """ListDeployedResourcesResponse

        The model defined in huaweicloud sdk

        :param results: 请求结果列表，详情请参见ResultDetail字段数据结构说明。
        :type results: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        
        super(ListDeployedResourcesResponse, self).__init__()

        self._results = None
        self.discriminator = None

        if results is not None:
            self.results = results

    @property
    def results(self):
        """Gets the results of this ListDeployedResourcesResponse.

        请求结果列表，详情请参见ResultDetail字段数据结构说明。

        :return: The results of this ListDeployedResourcesResponse.
        :rtype: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this ListDeployedResourcesResponse.

        请求结果列表，详情请参见ResultDetail字段数据结构说明。

        :param results: The results of this ListDeployedResourcesResponse.
        :type results: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDeployedResourcesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkscm-3.1.149-py2.py3-none-any.whl: huaweicloudsdkscm/v3/model/list_deployed_resources_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDeployedResourcesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'results': 'list[ResultDetail]'
    }

    attribute_map = {
        'results': 'results'
    }

    def __init__(self, results=None):
        r"""ListDeployedResourcesResponse

        The model defined in huaweicloud sdk

        :param results: 请求结果列表，详情请参见ResultDetail字段数据结构说明。
        :type results: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        
        super(ListDeployedResourcesResponse, self).__init__()

        self._results = None
        self.discriminator = None

        if results is not None:
            self.results = results

    @property
    def results(self):
        r"""Gets the results of this ListDeployedResourcesResponse.

        请求结果列表，详情请参见ResultDetail字段数据结构说明。

        :return: The results of this ListDeployedResourcesResponse.
        :rtype: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        return self._results

    @results.setter
    def results(self, results):
        r"""Sets the results of this ListDeployedResourcesResponse.

        请求结果列表，详情请参见ResultDetail字段数据结构说明。

        :param results: The results of this ListDeployedResourcesResponse.
        :type results: list[:class:`huaweicloudsdkscm.v3.ResultDetail`]
        """
        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDeployedResourcesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
